@@ -1,22 +1,21 @@
 /*
  *  Hamlib Flexradio backend
- *  Copyright (c) 2003-2007 by Stephane Fillod
+ *  Copyright (c) 2003-2012 by Stephane Fillod
  *
- *	$Id: flexradio.c,v 1.1 2007-11-07 19:06:44 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -40,6 +39,7 @@ DECLARE_INITRIG_BACKEND(flexradio)
 	rig_register(&sdr1k_rig_caps);
 	//rig_register(&sdr1krfe_rig_caps);
 	rig_register(&dttsp_rig_caps);
+	rig_register(&dttsp_udp_rig_caps);
 
 	return RIG_OK;
 }
