@@ -1,6 +1,7 @@
 /*
  *  Hamlib CI-V backend - description of IC-R10
  *  Copyright (c) 2000-2004 by Stephane Fillod
+ *  Copyright (c) 2017 Malcolm Herring
  *
  *
  *   This library is free software; you can redistribute it and/or
@@ -40,16 +41,17 @@
 #define ICR10_VFO_OPS (RIG_OP_NONE)
 #define ICR10_SCAN_OPS (RIG_SCAN_NONE)
 
-/*
- * FIXME: S-meter measurement
- */
-#define ICR10_STR_CAL UNKNOWN_IC_STR_CAL
+#define ICR10_STR_CAL { 2, \
+  { \
+    {  0, -60 }, /* S0 */ \
+    { 160, 60 } /* +60 */ \
+  } }
 
 static const struct icom_priv_caps icr10_priv_caps = {
-		0x52,	/* default address */
-		0,		/* 731 mode */
-    0,    /* no XCHG */
-		r8500_ts_sc_list	/* wrong, but don't have set_ts anyway */
+  0x52,	/* default address */
+  0,    /* 731 mode */
+  0,    /* no XCHG */
+  r8500_ts_sc_list	/* wrong, but don't have set_ts anyway */
 };
 
 const struct rig_caps icr10_caps = {
@@ -58,7 +60,7 @@ const struct rig_caps icr10_caps = {
 .mfg_name =  "Icom",
 .version =  BACKEND_VER,
 .copyright =  "LGPL",
-.status =  RIG_STATUS_UNTESTED,
+.status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_RECEIVER|RIG_FLAG_HANDHELD,
 .ptt_type =  RIG_PTT_NONE,
 .dcd_type =  RIG_DCD_RIG,
@@ -75,8 +77,8 @@ const struct rig_caps icr10_caps = {
 .retry =  3,
 .has_get_func =  ICR10_FUNC_ALL,
 .has_set_func =  ICR10_FUNC_ALL,
-.has_get_level =  ICR10_LEVEL_ALL,
-.has_set_level =  RIG_LEVEL_SET(ICR10_LEVEL_ALL),
+.has_get_level = ICR10_LEVEL_ALL,
+.has_set_level = RIG_LEVEL_NONE,
 .has_get_parm =  RIG_PARM_NONE,
 .has_set_parm =  RIG_PARM_NONE,	/* FIXME: parms */
 .level_gran = {
@@ -98,32 +100,32 @@ const struct rig_caps icr10_caps = {
 .chan_desc_sz =  0,
 
 .chan_list =  {
-		   RIG_CHAN_END,
-		},
+  RIG_CHAN_END,
+},
 
 .rx_range_list1 =   {
-	{kHz(500),GHz(1.3),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
-	RIG_FRNG_END, },
+  {kHz(500),GHz(1.3),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
+  RIG_FRNG_END, },
 .tx_range_list1 =   { RIG_FRNG_END, },
 
 .rx_range_list2 =   {
-	{kHz(500),MHz(823.9999),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
-	{MHz(849),MHz(868.9999),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
-	{MHz(894),GHz(1.3),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
-	RIG_FRNG_END, },
+  {kHz(500),MHz(823.9999),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
+  {MHz(849),MHz(868.9999),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
+  {MHz(894),GHz(1.3),ICR10_MODES,-1,-1,ICR10_VFO_ALL},
+  RIG_FRNG_END, },
 .tx_range_list2 =   { RIG_FRNG_END, },
 
 .tuning_steps = 	{
-	 {ICR10_MODES,Hz(100)},
-	 RIG_TS_END,
-	},
+  {ICR10_MODES,Hz(100)},
+  RIG_TS_END,
+},
 	/* mode/filter list, remember: order matters! */
 .filters = 	{
-		{RIG_MODE_SSB|RIG_MODE_CW, kHz(4)},
-		{RIG_MODE_AM|RIG_MODE_FM, kHz(15)},
-		{RIG_MODE_WFM, kHz(150)},
-		RIG_FLT_END,
-	},
+  {RIG_MODE_SSB|RIG_MODE_CW, kHz(4)},
+  {RIG_MODE_AM|RIG_MODE_FM, kHz(15)},
+  {RIG_MODE_WFM, kHz(150)},
+  RIG_FLT_END,
+},
 .str_cal = ICR10_STR_CAL,
 
 .cfgparams =  icom_cfg_params,
@@ -140,7 +142,6 @@ const struct rig_caps icr10_caps = {
 .get_freq =  icom_get_freq,
 .set_mode =  icom_set_mode,	/* TODO: do not pass bandwidth data */
 .get_mode =  icom_get_mode,
-/* .set_vfo =  icom_set_vfo, */
 
 .decode_event =  icom_decode_event,
 .get_level =  icom_get_level,
