@@ -2,21 +2,20 @@
  *  Hamlib Kachina backend - main file
  *  Copyright (c) 2001-2004 by Stephane Fillod
  *
- *	$Id: kachina.c,v 1.8 2006-10-07 17:42:14 csete Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -58,8 +57,8 @@
 #define DDS_CONST 2.2369621333
 #define DDS_BASE 75000000
 
-/* uppermost 2 bits of the high byte 
- * designating the antenna port in DDS calculation 
+/* uppermost 2 bits of the high byte
+ * designating the antenna port in DDS calculation
  */
 #define PORT_AB	0x00
 #define PORT_A	0x40
@@ -138,7 +137,7 @@ static void freq2dds(freq_t freq, int ant_port, unsigned char fbuf[4])
 		dds = DDS_CONST * ( DDS_BASE + freq);
 		dds_ulong = (unsigned long)dds;
 
-		/* 
+		/*
 		 * byte 0 transferred first,
 		 * dds is big endian format
 		 */
