@@ -37,7 +37,7 @@
 
 #define TS570_FUNC_ALL (RIG_FUNC_FAGC|RIG_FUNC_TSQL|RIG_FUNC_TONE|RIG_FUNC_NB|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_LOCK|RIG_FUNC_BC|RIG_FUNC_TUNER)
 
-#define TS570_LEVEL_ALL (RIG_LEVEL_PREAMP|RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_SQL|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_RFPOWER|RIG_LEVEL_MICGAIN|RIG_LEVEL_SLOPE_LOW|RIG_LEVEL_SLOPE_HIGH)
+#define TS570_LEVEL_ALL (RIG_LEVEL_PREAMP|RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_SQL|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_RFPOWER|RIG_LEVEL_MICGAIN|RIG_LEVEL_SLOPE_LOW|RIG_LEVEL_SLOPE_HIGH|RIG_LEVEL_KEYSPD)
 
 #define TS570_VFO (RIG_VFO_A|RIG_VFO_B)
 #define TS570_VFO_OP (RIG_OP_UP|RIG_OP_DOWN)
@@ -370,16 +370,17 @@ ts570_get_level (RIG * rig, vfo_t vfo, setting_t level, value_t * val)
 	if (levelint == 0) {
 	    val->i = 0;
 	} else {
-	    for (i=0; i<levelint && i<MAXDBLSTSIZ; i++)
+	    for (i=0; i<levelint && i<MAXDBLSTSIZ; i++) {
 		if (rig->state.preamp[i] == 0) {
 		    rig_debug(RIG_DEBUG_ERR,"%s: "
 			    "unexpected att level %d\n",
 			    __func__, levelint);
 		    return -RIG_EPROTO;
 		}
-		if (i != levelint)
-		    return -RIG_EINTERNAL;
-		val->i = rig->state.preamp[i-1];
+	    }
+	    if (i != levelint)
+	        return -RIG_EINTERNAL;
+	    val->i = rig->state.preamp[i-1];
 	}
 	break;
     default:
@@ -613,7 +614,7 @@ int ts570_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 	if (retval != RIG_OK)
 		return retval;
 
-        for (i = 0; i < abs(rint(rit/10)); i++)
+        for (i = 0; i < labs(lrint(rit/10)); i++)
         {
                 retval = kenwood_transaction(rig, buf, NULL, 0);
 		if (retval != RIG_OK)
@@ -653,7 +654,7 @@ int ts570_set_xit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 	if (retval != RIG_OK)
 		return retval;
 
-        for (i = 0; i < abs(rint(rit/10)); i++)
+        for (i = 0; i < labs(lrint(rit/10)); i++)
         {
                 retval = kenwood_transaction(rig, buf, NULL, 0);
 		if (retval != RIG_OK)
