@@ -41,7 +41,7 @@ const char* ts590_get_info(RIG *rig);
 
 #define TS590_LEVEL_ALL (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|\
         RIG_LEVEL_CWPITCH|RIG_LEVEL_METER|RIG_LEVEL_SWR|RIG_LEVEL_ALC|\
-        RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_STRENGTH|RIG_LEVEL_KEYSPD)
+        RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_RAWSTR|RIG_LEVEL_STRENGTH|RIG_LEVEL_KEYSPD)
 #define TS590_FUNC_ALL (RIG_FUNC_LOCK|RIG_FUNC_AIP|RIG_FUNC_TONE|\
         RIG_FUNC_NB|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_NR|RIG_FUNC_BC)
 
@@ -60,6 +60,19 @@ const char* ts590_get_info(RIG *rig);
         .flags=RIG_CHFLAG_SKIP \
         }
 
+#define TS590_STR_CAL {9, {\
+                       { 0, -60},\
+                       { 3, -48},\
+                       { 6, -36},\
+                       { 9, -24},\
+                       {12, -12},\
+                       {15,   0},\
+                       {20,  20},\
+                       {25,  40},\
+                       {30,  60}}\
+                       }
+
+
 static struct kenwood_priv_caps ts590_priv_caps = {
   .cmdtrm = EOM_KEN,
 };
@@ -187,6 +200,7 @@ const struct rig_caps ts590_caps = {
                 {RIG_MODE_FM, kHz(12)},
                 RIG_FLT_END,
         },
+  .str_cal = TS590_STR_CAL,
   .priv = (void *) &ts590_priv_caps,
   .rig_init = kenwood_init,
   .rig_cleanup = kenwood_cleanup,
@@ -354,6 +368,7 @@ const struct rig_caps ts590sg_caps = {
                 {RIG_MODE_FM, kHz(12)},
                 RIG_FLT_END,
         },
+  .str_cal = TS590_STR_CAL,
   .priv = (void *) &ts590_priv_caps,
   .rig_init = kenwood_init,
   .rig_cleanup = kenwood_cleanup,
