@@ -267,7 +267,7 @@ int ts850_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 	if (retval != RIG_OK)
 		return retval;
 
-	for (i = 0; i < abs(rint(rit/20)); i++)
+	for (i = 0; i < labs(lrint(rit/20)); i++)
 	{
 		retval = kenwood_transaction(rig, buf, NULL, 0);
 		if (retval != RIG_OK)
@@ -303,7 +303,7 @@ int ts850_set_xit(RIG * rig, vfo_t vfo, shortfreq_t xit)
 		c = 'D';
 	sprintf(buf, "R%c", c);
 
-	for (i = 0; i < abs(rint(xit/20)); i++)
+	for (i = 0; i < labs(lrint(xit/20)); i++)
 	{
 		retval = kenwood_transaction(rig, buf, NULL, 0);
 		if (retval != RIG_OK)
