@@ -33,7 +33,7 @@
 
 #ifdef _WIN32
 #define USE_FTDI_DLL
-#elif defined(HAVE_LIBUSB) && defined(HAVE_USB_H)
+#elif defined(HAVE_LIBUSB) && (defined(HAVE_LIBUSB_H) || defined(HAVE_LIBUSB_1_0_LIBUSB_H))
 #define USE_LIBUSB
 #endif
 
@@ -51,13 +51,13 @@ static int elektor507_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 static int elektor507_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
 static int elektor507_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 static int elektor507_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
-static int elektor507_set_ant(RIG * rig, vfo_t vfo, ant_t ant);
-static int elektor507_get_ant(RIG * rig, vfo_t vfo, ant_t *ant);
+static int elektor507_set_ant(RIG *rig, vfo_t vfo, ant_t ant);
+static int elektor507_get_ant(RIG *rig, vfo_t vfo, ant_t *ant);
 static int elektor507_set_conf(RIG *rig, token_t token, const char *val);
 static int elektor507_get_conf(RIG *rig, token_t token, char *val);
 
 
-static const char * elektor507_get_info(RIG *rig);
+static const char *elektor507_get_info(RIG *rig);
 
 /*
  * I2C addresses
@@ -79,7 +79,7 @@ static const char * elektor507_get_info(RIG *rig);
 
 static int cy_update_pll(RIG *rig, unsigned char IICadr);
 static int i2c_write_regs(RIG *rig, unsigned char IICadr, int reg_count, unsigned char reg_adr,
-		unsigned char reg_val1, unsigned char reg_val2, unsigned char reg_val3);
+			  unsigned char reg_val1, unsigned char reg_val2, unsigned char reg_val3);
 #define i2c_write_reg(rig, IICadr, reg_adr, reg_val) \
 		i2c_write_regs(rig, IICadr, 1, reg_adr, reg_val, 0, 0)
 
@@ -99,27 +99,26 @@ static int i2c_write_regs(RIG *rig, unsigned char IICadr, int reg_count, unsigne
 
 
 /* Some type definitions needed for dll access */
-typedef enum
-{
-  FT_OK = 0,
-  FT_INVALID_HANDLE = 1,
-  FT_DEVICE_NOT_FOUND = 2,
-  FT_DEVICE_NOT_OPENED = 3,
-  FT_IO_ERROR = 4,
-  FT_INSUFFICIENT_RESOURCES = 5,
-  FT_INVALID_PARAMETER = 6,
-  FT_SUCCESS = FT_OK,
-  FT_INVALID_BAUD_RATE = 7,
-  FT_DEVICE_NOT_OPENED_FOR_ERASE = 8,
-  FT_DEVICE_NOT_OPENED_FOR_WRITE = 9,
-  FT_FAILED_TO_WRITE_DEVICE = 10,
-  FT_EEPROM_READ_FAILED = 11,
-  FT_EEPROM_WRITE_FAILED = 12,
-  FT_EEPROM_ERASE_FAILED = 13,
-  FT_EEPROM_NOT_PRESENT = 14,
-  FT_EEPROM_NOT_PROGRAMMED = 15,
-  FT_INVALID_ARGS = 16,
-  FT_OTHER_ERROR = 17,
+typedef enum {
+	FT_OK = 0,
+	FT_INVALID_HANDLE = 1,
+	FT_DEVICE_NOT_FOUND = 2,
+	FT_DEVICE_NOT_OPENED = 3,
+	FT_IO_ERROR = 4,
+	FT_INSUFFICIENT_RESOURCES = 5,
+	FT_INVALID_PARAMETER = 6,
+	FT_SUCCESS = FT_OK,
+	FT_INVALID_BAUD_RATE = 7,
+	FT_DEVICE_NOT_OPENED_FOR_ERASE = 8,
+	FT_DEVICE_NOT_OPENED_FOR_WRITE = 9,
+	FT_FAILED_TO_WRITE_DEVICE = 10,
+	FT_EEPROM_READ_FAILED = 11,
+	FT_EEPROM_WRITE_FAILED = 12,
+	FT_EEPROM_ERASE_FAILED = 13,
+	FT_EEPROM_NOT_PRESENT = 14,
+	FT_EEPROM_NOT_PROGRAMMED = 15,
+	FT_INVALID_ARGS = 16,
+	FT_OTHER_ERROR = 17,
 } FT_Result;
 
 typedef FT_Result (__stdcall *FNCFT_Open)(int Index, unsigned long *ftHandle);
@@ -145,7 +144,12 @@ struct elektor507_extra_priv_data {
 
 
 #include <errno.h>
-#include <usb.h>
+
+#ifdef HAVE_LIBUSB_H
+# include <libusb.h>
+#elif defined HAVE_LIBUSB_1_0_LIBUSB_H
+# include <libusb-1.0/libusb.h>
+#endif
 
 
 #define USB_VID_FTDI		0x0403	/* Future Technology Devices International */
@@ -170,10 +174,12 @@ struct elektor507_extra_priv_data {
 #define TOK_XTALCAL	TOKEN_BACKEND(2)
 
 static const struct confparams elektor507_cfg_params[] = {
-	{ TOK_OSCFREQ, "osc_freq", "Oscillator freq", "Oscillator frequency in Hz",
-			"10000000", RIG_CONF_NUMERIC, { .n = { 0, MHz(30), 1 } }
+	{
+		TOK_OSCFREQ, "osc_freq", "Oscillator freq", "Oscillator frequency in Hz",
+		"10000000", RIG_CONF_NUMERIC, { .n = { 0, MHz(30), 1 } }
 	},
-	{ TOK_XTALCAL, "xtal_cal", "Xtal Cal", "Cristal calibration",
+	{
+		TOK_XTALCAL, "xtal_cal", "Xtal Cal", "Cristal calibration",
 		"132", RIG_CONF_NUMERIC, { .n = { 0, 255, 1 } }
 	},
 	{ RIG_CONF_END, NULL, }
@@ -197,7 +203,7 @@ struct elektor507_priv_data {
 	/* CY PLL stuff.
 	 * This is Qtotal & Ptotal values here.
 	 */
-	int P,Q,Div1N;
+	int P, Q, Div1N;
 
 	/* FTDI comm stuff */
 	unsigned char FT_port;
@@ -215,11 +221,13 @@ int elektor507_init(RIG *rig)
 	struct elektor507_priv_data *priv;
 	struct elektor507_extra_priv_data *extra_priv;
 
-	priv = (struct elektor507_priv_data*)calloc(sizeof(struct elektor507_priv_data), 1);
+	priv = (struct elektor507_priv_data *)calloc(sizeof(struct elektor507_priv_data), 1);
+
 	if (!priv) {
 		/* whoops! memory shortage! */
 		return -RIG_ENOMEM;
 	}
+
 	priv->xtal_cal = XTAL_CAL;
 	priv->osc_freq = OSCFREQ;
 	priv->ant = ANT_AUTO;
@@ -236,7 +244,7 @@ int elektor507_init(RIG *rig)
 
 	if (!extra_priv->dll) {
 		rig_debug(RIG_DEBUG_ERR, "%s: Unable to LoadLibrary %s\n",
-				__FUNCTION__, ELEKTOR507_DLL);
+			  __func__, ELEKTOR507_DLL);
 		free(priv);
 		return -RIG_EIO;	/* huh! */
 	}
@@ -261,7 +269,7 @@ int elektor507_init(RIG *rig)
 	extra_priv->FT_Write =
 		(FNCFT_Write) GetProcAddress(extra_priv->dll, "FT_Write");
 
-	rig->state.priv = (void*)priv;
+	rig->state.priv = (void *)priv;
 
 	return RIG_OK;
 }
@@ -273,28 +281,33 @@ int elektor507_ftdi_write_data(RIG *rig, void *FTOutBuf, unsigned long BufferSiz
 	FT_Result ret;
 	int Result;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called, %d bytes\n", __FUNCTION__, BufferSize);
+	rig_debug(RIG_DEBUG_TRACE, "%s called, %d bytes\n", __func__, BufferSize);
 
 	/* Open FTDI */
 	ret = extra_priv->FT_Open(0, &extra_priv->ftHandle);
+
 	if (ret != FT_OK)
 		return -RIG_EIO;
 
 	ret = extra_priv->FT_SetBitMode(extra_priv->ftHandle, 0xff, 1);
+
 	if (ret != FT_OK)
 		return -RIG_EIO;
 
 	ret = extra_priv->FT_SetBaudRate(extra_priv->ftHandle, 38400);
+
 	if (ret != FT_OK)
 		return -RIG_EIO;
 
 	ret = extra_priv->FT_Write(extra_priv->ftHandle, FTOutBuf, BufferSize, &Result);
+
 	if (ret != FT_OK) {
-		rig_debug(RIG_DEBUG_ERR,"FT_Write failed: %d, Result: %d\n", ret, Result);
+		rig_debug(RIG_DEBUG_ERR, "FT_Write failed: %d, Result: %d\n", ret, Result);
 		return -RIG_EIO;
 	}
 
 	ret = extra_priv->FT_Close(extra_priv->ftHandle);
+
 	if (ret != FT_OK)
 		return -RIG_EIO;
 
@@ -310,12 +323,13 @@ int elektor507_cleanup(RIG *rig)
 
 	if (rig->state.priv)
 		free(rig->state.priv);
+
 	rig->state.priv = NULL;
 
 	return RIG_OK;
 }
 
-const char * elektor507_get_info(RIG *rig)
+const char *elektor507_get_info(RIG *rig)
 {
 	static char buf[64];
 
@@ -338,7 +352,8 @@ int elektor507_init(RIG *rig)
 	hamlib_port_t *rp = &rig->state.rigport;
 	struct elektor507_priv_data *priv;
 
-	priv = (struct elektor507_priv_data*)calloc(sizeof(struct elektor507_priv_data), 1);
+	priv = (struct elektor507_priv_data *)calloc(sizeof(struct elektor507_priv_data), 1);
+
 	if (!priv) {
 		/* whoops! memory shortage! */
 		return -RIG_ENOMEM;
@@ -359,7 +374,7 @@ int elektor507_init(RIG *rig)
 	rp->parm.usb.iface = 0;
 	rp->parm.usb.alt = 0;	/* necessary ? */
 
-	rig->state.priv = (void*)priv;
+	rig->state.priv = (void *)priv;
 
 	return RIG_OK;
 }
@@ -371,39 +386,46 @@ int elektor507_cleanup(RIG *rig)
 
 	if (rig->state.priv)
 		free(rig->state.priv);
+
 	rig->state.priv = NULL;
 
 	return RIG_OK;
 }
 
-const char * elektor507_get_info(RIG *rig)
+/* Rem: not reentrant */
+const char *elektor507_get_info(RIG *rig)
 {
 	static char buf[64];
-	struct usb_dev_handle *udh = rig->state.rigport.handle;
-	struct usb_device *q = usb_device(udh);
+	libusb_device_handle *udh = rig->state.rigport.handle;
+	struct libusb_device_descriptor desc;
 
-	sprintf(buf, "USB dev %04d", q->descriptor.bcdDevice);
+	/* always succeeds since libusb-1.0.16 */
+	libusb_get_device_descriptor(libusb_get_device(udh), &desc);
+
+	sprintf(buf, "USB dev %04d", desc.bcdDevice);
 
 	return buf;
 }
 
 int elektor507_libusb_setup(RIG *rig)
 {
-	struct usb_dev_handle *udh = rig->state.rigport.handle;
+	libusb_device_handle *udh = rig->state.rigport.handle;
 	int ret;
-	unsigned short index=0, usb_val;
+	unsigned short index = 0, usb_val;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called\n", __FUNCTION__);
+	rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
 	/* Reset the ftdi device */
 #if 1
-	ret =  usb_control_msg(udh, 0x40, 0, 0, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+	ret =  libusb_control_transfer(udh, 0x40, 0, 0, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+
 	if (ret != 0) {
-		rig_debug (RIG_DEBUG_ERR, "%s: usb_control_msg reset failed: %s\n",
-					__FUNCTION__,
-					usb_strerror ());
+		rig_debug(RIG_DEBUG_ERR, "%s: libusb_control_transfer reset failed: %s\n",
+			  __func__,
+			  libusb_error_name(ret));
 		return -RIG_EIO;
 	}
+
 #endif
 
 	/*
@@ -412,11 +434,12 @@ int elektor507_libusb_setup(RIG *rig)
 	usb_val = 0xff; /* low byte: bitmask */
 	usb_val |= (0x01 << 8); /* Basic bitbang_mode: 0x01 */
 
-	ret = usb_control_msg(udh, 0x40, 0x0B, usb_val, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+	ret = libusb_control_transfer(udh, 0x40, 0x0B, usb_val, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+
 	if (ret != 0) {
-		rig_debug (RIG_DEBUG_ERR, "%s: usb_control_msg bitbangmode failed: %s\n",
-					__FUNCTION__,
-					usb_strerror ());
+		rig_debug(RIG_DEBUG_ERR, "%s: libusb_control_transfer bitbangmode failed: %s\n",
+			  __func__,
+			  libusb_error_name(ret));
 		return -RIG_EIO;
 	}
 
@@ -426,11 +449,12 @@ int elektor507_libusb_setup(RIG *rig)
 	 */
 	usb_val = 49230;	/* magic value for 38400 bauds */
 	index = 0;
-	ret = usb_control_msg(udh, 0x40, 3, usb_val, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+	ret = libusb_control_transfer(udh, 0x40, 3, usb_val, index, NULL, 0, FTDI_USB_WRITE_TIMEOUT);
+
 	if (ret != 0) {
-		rig_debug (RIG_DEBUG_ERR, "%s: usb_control_msg baudrate failed: %s\n",
-					__FUNCTION__,
-					usb_strerror ());
+		rig_debug(RIG_DEBUG_ERR, "%s: libusb_control_transfer baudrate failed: %s\n",
+			  __func__,
+			  libusb_error_name(ret));
 		return -RIG_EIO;
 	}
 
@@ -439,18 +463,17 @@ int elektor507_libusb_setup(RIG *rig)
 
 int elektor507_ftdi_write_data(RIG *rig, void *FTOutBuf, unsigned long BufferSize)
 {
-	struct usb_dev_handle *udh = rig->state.rigport.handle;
-	int ret;
+	libusb_device_handle *udh = rig->state.rigport.handle;
+	int ret, actual_length;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called, %d bytes\n", __FUNCTION__, BufferSize);
+	rig_debug(RIG_DEBUG_TRACE, "%s called, %d bytes\n", __func__, BufferSize);
+
+	ret = libusb_bulk_transfer(udh, FTDI_IN_EP, FTOutBuf, BufferSize, &actual_length, FTDI_USB_WRITE_TIMEOUT);
 
-	ret = usb_bulk_write(udh, FTDI_IN_EP, FTOutBuf, BufferSize, FTDI_USB_WRITE_TIMEOUT);
 	if (ret < 0) {
-		/* we get EPIPE if the firmware stalls the endpoint. */
-		if (errno != EPIPE)
-			rig_debug (RIG_DEBUG_ERR,
-					"usb_bulk_write failed: %s\n",
-					usb_strerror ());
+		rig_debug(RIG_DEBUG_ERR,
+			  "usb_bulk_write failed: %s\n",
+			  libusb_error_name(ret));
 		return -RIG_EIO;
 	}
 
@@ -492,88 +515,88 @@ int elektor507_ftdi_write_data(RIG *rig, void *FTOutBuf, unsigned long BufferSiz
  */
 
 const struct rig_caps elektor507_caps = {
-.rig_model =  RIG_MODEL_ELEKTOR507,
-.model_name = "Elektor SDR-USB",
-.mfg_name =  "Elektor",
-.version =  "0.3.1",
-.copyright =  "LGPL",
-.status =  RIG_STATUS_STABLE,
-.rig_type =  RIG_TYPE_TUNER,
-.ptt_type =  RIG_PTT_NONE,
-.dcd_type =  RIG_DCD_NONE,
+	.rig_model =		RIG_MODEL_ELEKTOR507,
+	.model_name =		"Elektor SDR-USB",
+	.mfg_name =		"Elektor",
+	.version =		"0.3.2",
+	.copyright =		"LGPL",
+	.status =		RIG_STATUS_STABLE,
+	.rig_type =		RIG_TYPE_TUNER,
+	.ptt_type =		RIG_PTT_NONE,
+	.dcd_type =		RIG_DCD_NONE,
 #ifdef USE_LIBUSB
-.port_type =  RIG_PORT_USB,
+	.port_type =		RIG_PORT_USB,
 #else
-.port_type =  RIG_PORT_NONE,
+	.port_type =		RIG_PORT_NONE,
 #endif
-.serial_rate_min =  9600,
-.serial_rate_max =  9600,
-.serial_data_bits =  8,
-.serial_stop_bits =  1,
-.serial_parity =  RIG_PARITY_NONE,
-.serial_handshake =  RIG_HANDSHAKE_NONE,
-.write_delay =  0,
-.post_write_delay =  0,
-.timeout =  200,
-.retry = 0,
+	.serial_rate_min =	9600,
+	.serial_rate_max =	9600,
+	.serial_data_bits =	8,
+	.serial_stop_bits =	1,
+	.serial_parity =	RIG_PARITY_NONE,
+	.serial_handshake =	RIG_HANDSHAKE_NONE,
+	.write_delay =		0,
+	.post_write_delay =	0,
+	.timeout =		200,
+	.retry =		0,
 
-.has_get_func =  ELEKTOR507_FUNC,
-.has_set_func =  ELEKTOR507_FUNC,
-.has_get_level =  ELEKTOR507_LEVEL_ALL,
-.has_set_level =  RIG_LEVEL_SET(ELEKTOR507_LEVEL_ALL),
-.has_get_parm =  ELEKTOR507_PARM_ALL,
-.has_set_parm =  RIG_PARM_SET(ELEKTOR507_PARM_ALL),
-.level_gran =  {},
-.parm_gran =  {},
-.ctcss_list =  NULL,
-.dcs_list =  NULL,
-.preamp =   { RIG_DBLST_END },
-.attenuator =   { 10, 20, RIG_DBLST_END },
-.max_rit =  Hz(0),
-.max_xit =  Hz(0),
-.max_ifshift =  Hz(0),
-.targetable_vfo =  0,
-.transceive =  RIG_TRN_OFF,
-.bank_qty =   0,
-.chan_desc_sz =  0,
+	.has_get_func =		ELEKTOR507_FUNC,
+	.has_set_func =		ELEKTOR507_FUNC,
+	.has_get_level =	ELEKTOR507_LEVEL_ALL,
+	.has_set_level =	RIG_LEVEL_SET(ELEKTOR507_LEVEL_ALL),
+	.has_get_parm =		ELEKTOR507_PARM_ALL,
+	.has_set_parm =		RIG_PARM_SET(ELEKTOR507_PARM_ALL),
+	.level_gran =		{},
+	.parm_gran =		{},
+	.ctcss_list =		NULL,
+	.dcs_list =		NULL,
+	.preamp =		{ RIG_DBLST_END },
+	.attenuator =		{ 10, 20, RIG_DBLST_END },
+	.max_rit =		Hz(0),
+	.max_xit =		Hz(0),
+	.max_ifshift =		Hz(0),
+	.targetable_vfo =	0,
+	.transceive =		RIG_TRN_OFF,
+	.bank_qty =		0,
+	.chan_desc_sz =		0,
 
-.chan_list =  { RIG_CHAN_END, },
+	.chan_list =		{ RIG_CHAN_END, },
 
-.rx_range_list1 =  {
-    {kHz(30),MHz(30)-kHz(1),ELEKTOR507_MODES,-1,-1,ELEKTOR507_VFO, ELEKTOR507_ANT},
-	RIG_FRNG_END,
-  },
-.tx_range_list1 =  { RIG_FRNG_END, },
-.rx_range_list2 =  {
-    {kHz(30),MHz(30)-kHz(1),ELEKTOR507_MODES,-1,-1,ELEKTOR507_VFO, ELEKTOR507_ANT},
-	RIG_FRNG_END,
-  },
-.tx_range_list2 =  { RIG_FRNG_END, },
-.tuning_steps =  {
-	 {ELEKTOR507_MODES,kHz(1)},
-	 RIG_TS_END,
+	.rx_range_list1 = {
+		{kHz(30), MHz(30) - kHz(1), ELEKTOR507_MODES, -1, -1, ELEKTOR507_VFO, ELEKTOR507_ANT},
+		RIG_FRNG_END,
 	},
-        /* mode/filter list, remember: order matters! */
-.filters =  {
+	.tx_range_list1 = { RIG_FRNG_END, },
+	.rx_range_list2 = {
+		{kHz(30), MHz(30) - kHz(1), ELEKTOR507_MODES, -1, -1, ELEKTOR507_VFO, ELEKTOR507_ANT},
+		RIG_FRNG_END,
+	},
+	.tx_range_list2 = { RIG_FRNG_END, },
+	.tuning_steps = {
+		{ELEKTOR507_MODES, kHz(1)},
+		RIG_TS_END,
+	},
+	/* mode/filter list, remember: order matters! */
+	.filters = {
 		{RIG_MODE_USB, kHz(24)},	/* bandpass may be more */
 		RIG_FLT_END,
 	},
-.cfgparams =  elektor507_cfg_params,
+	.cfgparams =		elektor507_cfg_params,
 
-.rig_init =     elektor507_init,
-.rig_cleanup =  elektor507_cleanup,
-.rig_open =     elektor507_open,
-.set_conf =  elektor507_set_conf,
-.get_conf =  elektor507_get_conf,
+	.rig_init =		elektor507_init,
+	.rig_cleanup =		elektor507_cleanup,
+	.rig_open =		elektor507_open,
+	.set_conf =		elektor507_set_conf,
+	.get_conf =		elektor507_get_conf,
 
 
-.set_freq    =  elektor507_set_freq,
-.get_freq    =  elektor507_get_freq,
-.set_level   =  elektor507_set_level,
-.get_level   =  elektor507_get_level,
-.set_ant     =  elektor507_set_ant,
-.get_ant     =  elektor507_get_ant,
-.get_info    =  elektor507_get_info,
+	.set_freq =		elektor507_set_freq,
+	.get_freq =		elektor507_get_freq,
+	.set_level =		elektor507_set_level,
+	.get_level =		elektor507_get_level,
+	.set_ant =		elektor507_set_ant,
+	.get_ant =		elektor507_get_ant,
+	.get_info =		elektor507_get_info,
 
 };
 
@@ -583,19 +606,22 @@ int elektor507_set_conf(RIG *rig, token_t token, const char *val)
 	struct elektor507_priv_data *priv;
 	freq_t freq;
 
-	priv = (struct elektor507_priv_data*)rig->state.priv;
+	priv = (struct elektor507_priv_data *)rig->state.priv;
 
-	switch(token) {
-		case TOK_OSCFREQ:
-			sscanf(val, "%"SCNfreq, &freq);
-			priv->osc_freq = freq / kHz(1);
-			break;
-		case TOK_XTALCAL:
-			sscanf(val, "%u", &priv->xtal_cal);
-			break;
-		default:
-			return -RIG_EINVAL;
+	switch (token) {
+	case TOK_OSCFREQ:
+		sscanf(val, "%"SCNfreq, &freq);
+		priv->osc_freq = freq / kHz(1);
+		break;
+
+	case TOK_XTALCAL:
+		sscanf(val, "%u", &priv->xtal_cal);
+		break;
+
+	default:
+		return -RIG_EINVAL;
 	}
+
 	return RIG_OK;
 }
 
@@ -603,18 +629,21 @@ int elektor507_get_conf(RIG *rig, token_t token, char *val)
 {
 	struct elektor507_priv_data *priv;
 
-	priv = (struct elektor507_priv_data*)rig->state.priv;
+	priv = (struct elektor507_priv_data *)rig->state.priv;
 
-	switch(token) {
-		case TOK_OSCFREQ:
-			sprintf(val, "%"PRIfreq, priv->osc_freq*kHz(1));
-			break;
-		case TOK_XTALCAL:
-			sprintf(val, "%u", priv->xtal_cal);
-			break;
-		default:
-			return -RIG_EINVAL;
+	switch (token) {
+	case TOK_OSCFREQ:
+		sprintf(val, "%"PRIfreq, priv->osc_freq * kHz(1));
+		break;
+
+	case TOK_XTALCAL:
+		sprintf(val, "%u", priv->xtal_cal);
+		break;
+
+	default:
+		return -RIG_EINVAL;
 	}
+
 	return RIG_OK;
 }
 
@@ -625,15 +654,17 @@ int elektor507_open(RIG *rig)
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
 	int ret;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called\n", __FUNCTION__);
+	rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
 	/*
 	 * Setup the FT232R.
 	 */
 #ifdef USE_LIBUSB
 	ret = elektor507_libusb_setup(rig);
+
 	if (ret != RIG_OK)
 		return ret;
+
 #endif
 
 	/* Init the FT232R port to SCL/SDA high, Mux A0, Att 0 */
@@ -646,33 +677,40 @@ int elektor507_open(RIG *rig)
 
 	/* Enable only CLOCK5. CLOCK3 will be on demand in set_ant() */
 	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, CLKOE_REG, 0x20);
+
 	if (ret != 0)
 		return ret;
 
 	/* DIV1N set to safe default */
 	priv->Div1N = 8;
 	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, DIV1_REG, priv->Div1N);
+
 	if (ret != 0)
 		return ret;
 
 #if 0
 	/* Xtal gain setting */
 	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, XTALCTL_REG, 0x32);
+
 	if (ret != 0)
 		return ret;
 
 	/* CapLoad set to middle */
 	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, CAPLOAD_REG, priv->xtal_cal);
+
 	if (ret != 0)
 		return ret;
+
 #endif
 	/* CLKSRC: CLOCK3=DIV2CLK/2, CLOCK5=DIV1CLK/DIV1N */
 	ret = i2c_write_regs(rig, CY_I2C_RAM_ADR, 3, CLKSRC_REG, 0x02, 0x8e, 0x47);
+
 	if (ret != 0)
 		return ret;
 
 	/* DIV2SRC from REF */
 	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, DIV2_REG, 0x88);
+
 	if (ret != 0)
 		return ret;
 
@@ -691,40 +729,28 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 
 	Freq = freq / kHz(1);
 
-	if (Freq > 19 && Freq < 60)
-	{
-		priv->Div1N = (2500 + Freq/2) / Freq + 128;
+	if (Freq > 19 && Freq < 60) {
+		priv->Div1N = (2500 + Freq / 2) / Freq + 128;
 		priv->P = 1000;
 		priv->Q = 40;
 		return;
-	}
-	else
-	if (Freq > 59 && Freq < 801)
-	{
+	} else if (Freq > 59 && Freq < 801) {
 		priv->Div1N = 125;
 		priv->P = Freq * 2;
 		priv->Q = 40;
 		return;
-	}
-	else
-	if (Freq > 800 && Freq < 2001)
-	{
+	} else if (Freq > 800 && Freq < 2001) {
 		priv->Div1N = 50;
 		priv->P = Freq;
 		priv->Q = 50;
 		return;
-	}
-	else
-	if (Freq > 2000 && Freq < 4001)
+	} else if (Freq > 2000 && Freq < 4001)
 		priv->Div1N = 25;
-	else
-	if (Freq > 4000 && Freq < 10001)
+	else if (Freq > 4000 && Freq < 10001)
 		priv->Div1N = 10;
-	else
-	if (Freq > 10000 && Freq < 20001)
+	else if (Freq > 10000 && Freq < 20001)
 		priv->Div1N = 5;
-	else
-	if (Freq > 20000 && Freq < 30001)
+	else if (Freq > 20000 && Freq < 30001)
 		priv->Div1N = 4;
 
 	Min = priv->osc_freq;
@@ -739,26 +765,28 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 	   + P*(REF/Qtotal) must not be above 400 MHz or below 100 MHz
 	  */
 #if 1
-	q_max = priv->osc_freq/250;
+	q_max = priv->osc_freq / 250;
 #else
 	q_max = 100;
 #endif
+
 	for (q = q_max; q >= 10; q--) {
 		for (p = 500; p <= 2000; p++) {
-			VCO = ((double)priv->osc_freq/q)*p;
+			VCO = ((double)priv->osc_freq / q) * p;
 
-			if (fabs(4*freq-VCO/priv->Div1N) < Min) {
-				Min = fabs(4*freq - VCO/priv->Div1N);
+			if (fabs(4 * freq - VCO / priv->Div1N) < Min) {
+				Min = fabs(4 * freq - VCO / priv->Div1N);
 				priv->Q = q;
 				priv->P = p;
 			}
 		}
 	}
 
-	VCO = ((double)priv->osc_freq/priv->Q)*priv->P;
+	VCO = ((double)priv->osc_freq / priv->Q) * priv->P;
+
 	if (VCO < 100e3 || VCO > 400e3)
 		rig_debug(RIG_DEBUG_VERBOSE, "%s: Unstable parameters for VCO=%.1f\n",
-			__FUNCTION__, VCO);
+			  __func__, VCO);
 }
 #endif	/* ORIG_ALGORITHM */
 
@@ -770,7 +798,7 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 	int p, q, div1n, q_max;
 
 	Min = priv->osc_freq;
-	freq4 = freq*4/kHz(1);
+	freq4 = freq * 4 / kHz(1);
 
 #define vco_min 100e3
 #define vco_max 500e3
@@ -783,16 +811,19 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 	   + P*(REF/Qtotal) must not be above 400 MHz or below 100 MHz
 	  */
 #if 1
-	q_max = priv->osc_freq/250;
+	q_max = priv->osc_freq / 250;
 #else
 	q_max = 100;
 #endif
-	div1n_min = vco_min/freq4;
+	div1n_min = vco_min / freq4;
+
 	if (div1n_min < 2)
 		div1n_min = 2;
 	else if (div1n_min > 127)
 		div1n_min = 127;
-	div1n_max = vco_max/freq4;
+
+	div1n_max = vco_max / freq4;
+
 	if (div1n_max > 127)
 		div1n_max = 127;
 	else if (div1n_max < 2)
@@ -803,19 +834,24 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 		// P/Qtotal = FREQ4*DIV1N/REF
 		// (Q*int(r) + frac(r)*Q)/Q
 		for (q = q_max; q >= 2; q--) {
-			p = q*freq4*div1n/priv->osc_freq;
+			p = q * freq4 * div1n / priv->osc_freq;
 #if 1
+
 			if (p < 16 || p > 1023)
 				continue;
+
 #endif
 
-			VCO = ((double)priv->osc_freq/q)*p;
+			VCO = ((double)priv->osc_freq / q) * p;
 #if 1
+
 			if (VCO < vco_min || VCO > vco_max)
 				continue;
+
 #endif
-			if (fabs(freq4-VCO/div1n) < Min) {
-				Min = fabs(freq4 - VCO/div1n);
+
+			if (fabs(freq4 - VCO / div1n) < Min) {
+				Min = fabs(freq4 - VCO / div1n);
 				priv->Div1N = div1n;
 				priv->Q = q;
 				priv->P = p;
@@ -823,10 +859,11 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 		}
 	}
 
-	VCO = ((double)priv->osc_freq/priv->Q)*priv->P;
+	VCO = ((double)priv->osc_freq / priv->Q) * priv->P;
+
 	if (VCO < vco_min || VCO > 400e3)
 		rig_debug(RIG_DEBUG_VERBOSE, "%s: Unstable parameters for VCO=%.1f\n",
-			__FUNCTION__, VCO);
+			  __func__, VCO);
 }
 #endif	/* default alternative to ORIG_ALGORITHM */
 
@@ -835,7 +872,7 @@ static void find_P_Q_DIV1N(struct elektor507_priv_data *priv, freq_t freq)
 static void find_P_Q_DIV1N(
 	struct elektor507_priv_data *priv,
 	freq_t freq)
-	{
+{
 #define VCO_MIN 100000000
 #define VCO_MAX 400000000
 	int Ptotal, Pmin, Pmax;
@@ -848,41 +885,43 @@ static void find_P_Q_DIV1N(
 
 	/* For stable operation: Ref/Qtotal must not fall below 250kHz */
 	/* Qmax = (int) ( Ref / 250000); */
-	for (Qtotal = 2; Qtotal <= Qmax; Qtotal++)
-		{
-		REFdivQ = ( Ref / Qtotal);
+	for (Qtotal = 2; Qtotal <= Qmax; Qtotal++) {
+		REFdivQ = (Ref / Qtotal);
 
 		/* For stable operation: Ptotal*(Ref/Qtotal) must be ... */
-		Pmin = (int) ( VCO_MIN / REFdivQ); /* ... >= 100mHz */
-		Pmax = (int) ( VCO_MAX / REFdivQ); /* ... <= 400mHz */
-		for (Ptotal = Pmin; Ptotal <= Pmax; Ptotal++)
-			{
+		Pmin = (int)(VCO_MIN / REFdivQ);   /* ... >= 100mHz */
+		Pmax = (int)(VCO_MAX / REFdivQ);   /* ... <= 400mHz */
+
+		for (Ptotal = Pmin; Ptotal <= Pmax; Ptotal++) {
 			PmulREFdivQ = Ptotal * REFdivQ;
 
-			Div1N = (int) ((PmulREFdivQ + freq4 / 2) / freq4);
+			Div1N = (int)((PmulREFdivQ + freq4 / 2) / freq4);
+
 			if (Div1N < 2)
 				Div1N = 2;
+
 			if (Div1N > 127)
 				Div1N = 127;
 
 			newdelta = fabs((PmulREFdivQ / Div1N) - freq4);
-			if (newdelta < delta)
-				{ /* save best (P,Q,N) */
+
+			if (newdelta < delta) {
+				/* save best (P,Q,N) */
 				delta = newdelta;
 				priv->P = Ptotal;
 				priv->Q = Qtotal;
 				priv->Div1N = Div1N;
-				}
 			}
 		}
 	}
+}
 #endif /* AC6SL version 5-Aug-2010 */
 
 int elektor507_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
 	freq_t final_freq;
-	int ret=0;
+	int ret = 0;
 	int Mux;
 
 	if (priv->ant == ANT_AUTO) {
@@ -894,6 +933,7 @@ int elektor507_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 			/* Select A2, high pass */
 			Mux = 2;
 		}
+
 		priv->FT_port &= 0x63;	//0,1 = I2C, 2,3,4=MUX, 5,6=Attenuator
 		priv->FT_port |= Mux << 2;
 	}
@@ -902,12 +942,12 @@ int elektor507_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 	elektor507_get_freq(rig, vfo, &final_freq);
 	rig_debug(RIG_DEBUG_VERBOSE, "%s: Freq=%.0f kHz, delta=%d Hz, Div1N=%d, P=%d, Q=%d, FREQ_ALGORITHM=%d\n",
-			__FUNCTION__, freq/kHz(1), (int)(final_freq-freq), priv->Div1N, priv->P, priv->Q, FREQ_ALGORITHM);
+		  __func__, freq / kHz(1), (int)(final_freq - freq), priv->Div1N, priv->P, priv->Q, FREQ_ALGORITHM);
 
-	if ((double)priv->osc_freq/priv->Q < 250)
+	if ((double)priv->osc_freq / priv->Q < 250)
 		rig_debug(RIG_DEBUG_WARN,
-				"%s: Unstable parameters for REF/Qtotal=%.1f\n",
-			__FUNCTION__, (double)priv->osc_freq/priv->Q);
+			  "%s: Unstable parameters for REF/Qtotal=%.1f\n",
+			  __func__, (double)priv->osc_freq / priv->Q);
 
 	ret = cy_update_pll(rig, CY_I2C_RAM_ADR);
 
@@ -930,23 +970,27 @@ int elektor507_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 int elektor507_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
-	int ret=0;
-	int att=0;
+	int ret = 0;
+	int att = 0;
 
-	switch(level) {
+	switch (level) {
 	case RIG_LEVEL_ATT:
+
 		/* val.i */
 		/* FTDI: DSR, DCD */
 
 		switch (val.i) {
-			case 0: att = 0; break;
-			case 10: att = 1; break;
-			case 20: att = 2; break;
-			default: return -RIG_EINVAL;
+		case 0: att = 0; break;
+
+		case 10: att = 1; break;
+
+		case 20: att = 2; break;
+
+		default: return -RIG_EINVAL;
 		}
 
 		priv->FT_port &= 0x1f;
-		priv->FT_port |= (att&0x3) << 5;
+		priv->FT_port |= (att & 0x3) << 5;
 
 		ret = elektor507_ftdi_write_data(rig, &priv->FT_port, 1);
 
@@ -962,17 +1006,20 @@ int elektor507_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int elektor507_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
-	int ret=0;
+	int ret = 0;
 
-	switch(level) {
+	switch (level) {
 	case RIG_LEVEL_ATT:
 
 		switch ((priv->FT_port >> 5) & 3) {
-			case 0: val->i = 0; break;
-			case 1: val->i = 10; break;
-			case 2: val->i = 20; break;
-			default:
-				ret = -RIG_EINVAL;
+		case 0: val->i = 0; break;
+
+		case 1: val->i = 10; break;
+
+		case 2: val->i = 20; break;
+
+		default:
+			ret = -RIG_EINVAL;
 		}
 
 		break;
@@ -985,12 +1032,12 @@ int elektor507_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 }
 
 
-int elektor507_set_ant(RIG * rig, vfo_t vfo, ant_t ant)
+int elektor507_set_ant(RIG *rig, vfo_t vfo, ant_t ant)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
 	int ret, Mux;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called\n", __FUNCTION__);
+	rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
 	/*
 	 * FTDI: RTS, CTS, DTR
@@ -1000,13 +1047,17 @@ int elektor507_set_ant(RIG * rig, vfo_t vfo, ant_t ant)
 	 * ANT1->A1/A2, ANT2->A3, ANT3->A7
 	 */
 
-	switch(ant) {
+	switch (ant) {
 	case RIG_ANT_1: Mux = 0; break;	/* Mux will be updated upon next set_freq */
+
 	case RIG_ANT_2: Mux = 3; break;	/* ANT_EXT */
+
 	case RIG_ANT_3: Mux = 7; break; /* ANT_TEST_CLK */
+
 	default:
-			return -RIG_EINVAL;
+		return -RIG_EINVAL;
 	}
+
 	priv->ant = ant;
 
 	priv->FT_port &= 0x63;	//0,1 = I2C, 2,3,4=MUX, 5,6=Attenuator
@@ -1016,13 +1067,13 @@ int elektor507_set_ant(RIG * rig, vfo_t vfo, ant_t ant)
 	ret = elektor507_ftdi_write_data(rig, &priv->FT_port, 1);
 #else
 	/* Enable CLOCK3 on demand */
-	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, CLKOE_REG, 0x20 | (ant==RIG_ANT_3 ? 0x04 : 0));
+	ret = i2c_write_reg(rig, CY_I2C_RAM_ADR, CLKOE_REG, 0x20 | (ant == RIG_ANT_3 ? 0x04 : 0));
 #endif
 
 	return (ret != 0) ? -RIG_EIO : RIG_OK;
 }
 
-int elektor507_get_ant(RIG * rig, vfo_t vfo, ant_t *ant)
+int elektor507_get_ant(RIG *rig, vfo_t vfo, ant_t *ant)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
 
@@ -1047,53 +1098,55 @@ static int cy_update_pll(RIG *rig, unsigned char IICadr)
 	/*
 	 * PLL Pump setting according to table 9
 	 */
-        if (priv->P < 45)
+	if (priv->P < 45)
 		Pump = 0;
-	else
-        if (priv->P < 480)
+	else if (priv->P < 480)
 		Pump = 1;
-	else
-        if (priv->P < 640)
+	else if (priv->P < 640)
 		Pump = 2;
-	else
-        if (priv->P < 800)
+	else if (priv->P < 800)
 		Pump = 3;
 	else
 		Pump = 4;
 
 	P0 = priv->P & 0x01;
 	R40 = (((priv->P >> 1) - 4) >> 8) | (Pump << 2) | 0xc0;
-	R41 =  ((priv->P >> 1) - 4) & 0xff;
-	R42 = (priv->Q - 2) | (P0<<7);
+	R41 = ((priv->P >> 1) - 4) & 0xff;
+	R42 = (priv->Q - 2) | (P0 << 7);
 
 
 	ret = i2c_write_regs(rig, IICadr, 3, PUMPCOUNTERS_REG, R40, R41, R42);
+
 	if (ret != 0)
 		return ret;
 
 	switch (priv->Div1N) {
-		case 2:
-			/* Fixed /2 divider option */
-			Clk3_src = 0x80;
-			Div1N = 8;
-			break;
-		case 3:
-			/* Fixed /3 divider option */
-			Clk3_src = 0xc0;
-			Div1N = 6;
-			break;
-		default:
-			Div1N = priv->Div1N;
-			Clk3_src = 0x40;
+	case 2:
+		/* Fixed /2 divider option */
+		Clk3_src = 0x80;
+		Div1N = 8;
+		break;
+
+	case 3:
+		/* Fixed /3 divider option */
+		Clk3_src = 0xc0;
+		Div1N = 6;
+		break;
+
+	default:
+		Div1N = priv->Div1N;
+		Clk3_src = 0x40;
 	}
 
 	ret = i2c_write_reg(rig, IICadr, DIV1_REG, Div1N);
+
 	if (ret != 0)
 		return ret;
 
 
 	/* Set 2 low bits of CLKSRC for CLOCK5. DIV1CLK is set already */
-	ret = i2c_write_reg(rig, IICadr, CLKSRC_REG+2, Clk3_src|0x07);
+	ret = i2c_write_reg(rig, IICadr, CLKSRC_REG + 2, Clk3_src | 0x07);
+
 	if (ret != 0)
 		return ret;
 
@@ -1107,6 +1160,7 @@ static void ftdi_SCL(RIG *rig, int d)
 
 	if (priv->Buf_adr >= FT_OUT_BUFFER_MAX)
 		return;
+
 	/*
 	 * FTDI RXD->SCL
 	 */
@@ -1125,6 +1179,7 @@ static void ftdi_SDA(RIG *rig, int d)
 
 	if (priv->Buf_adr >= FT_OUT_BUFFER_MAX)
 		return;
+
 	/*
 	 * FTDI TXD->SDA
 	 */
@@ -1171,13 +1226,13 @@ static void ftdi_I2C_Write_Byte(RIG *rig, unsigned char c)
 {
 	int i;
 
-	for (i=7; i>=0; i--)
-	{
-		ftdi_SDA(rig, c & (1<<i));          /* SDA value */
+	for (i = 7; i >= 0; i--) {
+		ftdi_SDA(rig, c & (1 << i));        /* SDA value */
 
 		ftdi_SCL(rig, 1);
 		ftdi_SCL(rig, 0);
 	}
+
 	ftdi_SDA(rig, 1);
 	ftdi_SCL(rig, 1);
 	ftdi_SCL(rig, 0);
@@ -1185,7 +1240,7 @@ static void ftdi_I2C_Write_Byte(RIG *rig, unsigned char c)
 
 
 int i2c_write_regs(RIG *rig, unsigned char IICadr, int reg_count, unsigned char reg_adr,
-		unsigned char reg_val1, unsigned char reg_val2, unsigned char reg_val3)
+		   unsigned char reg_val1, unsigned char reg_val2, unsigned char reg_val3)
 {
 	struct elektor507_priv_data *priv = (struct elektor507_priv_data *)rig->state.priv;
 	int ret;
@@ -1195,15 +1250,17 @@ int i2c_write_regs(RIG *rig, unsigned char IICadr, int reg_count, unsigned char
 
 	ftdi_I2C_Init(rig);
 	ftdi_I2C_Start(rig);
-	ftdi_I2C_Write_Byte (rig, IICadr);
-	ftdi_I2C_Write_Byte (rig, reg_adr);
+	ftdi_I2C_Write_Byte(rig, IICadr);
+	ftdi_I2C_Write_Byte(rig, reg_adr);
 
 	if (reg_count >= 1)
-		ftdi_I2C_Write_Byte (rig, reg_val1);
+		ftdi_I2C_Write_Byte(rig, reg_val1);
+
 	if (reg_count >= 2)
-		ftdi_I2C_Write_Byte (rig, reg_val2);
+		ftdi_I2C_Write_Byte(rig, reg_val2);
+
 	if (reg_count >= 3)
-		ftdi_I2C_Write_Byte (rig, reg_val3);
+		ftdi_I2C_Write_Byte(rig, reg_val3);
 
 	ftdi_I2C_Stop(rig);
 	//usleep(10000);
@@ -1212,26 +1269,27 @@ int i2c_write_regs(RIG *rig, unsigned char IICadr, int reg_count, unsigned char
 
 	if (ret != 0)
 		return -RIG_EIO;
+
 	return 0;
 }
 
 
 #if 0
 static const unsigned char ftdi_code[256] = {
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x34, 0x08, 0x5a, 0x24/*0x6f*/, 0x00, 0x14, 0x0a, 0x00, 0x08, 0x88,
-  0x50, 0x04, 0x32, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0xd1, 0x2b, 0x17, 0x00, 0xfe, 0xfe, 0x7f, 0x84, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
-  0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x34, 0x08, 0x5a, 0x24/*0x6f*/, 0x00, 0x14, 0x0a, 0x00, 0x08, 0x88,
+	0x50, 0x04, 0x32, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0xd1, 0x2b, 0x17, 0x00, 0xfe, 0xfe, 0x7f, 0x84, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32,
+	0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32, 0x10, 0x32
 };
 
 int load_ftdi_code(RIG *rig, unsigned char IICadr, const unsigned char code[])
@@ -1240,24 +1298,24 @@ int load_ftdi_code(RIG *rig, unsigned char IICadr, const unsigned char code[])
 	int ret;
 	int i, j;
 
-	rig_debug(RIG_DEBUG_TRACE,"%s called\n", __FUNCTION__);
+	rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
-	for (i = 0; i<16; i++)
-	{
+	for (i = 0; i < 16; i++) {
 		/* Start with a new buffer */
 		priv->Buf_adr = 0;
 		ftdi_I2C_Init(rig);
 		ftdi_I2C_Start(rig);
-		ftdi_I2C_Write_Byte (rig, IICadr);
-		ftdi_I2C_Write_Byte (rig, i*16);
+		ftdi_I2C_Write_Byte(rig, IICadr);
+		ftdi_I2C_Write_Byte(rig, i * 16);
 
-		for (j = 0; j<16; j++)
-		{
-			ftdi_I2C_Write_Byte (rig, code[i*16+j]);
+		for (j = 0; j < 16; j++) {
+			ftdi_I2C_Write_Byte(rig, code[i * 16 + j]);
 		}
+
 		ftdi_I2C_Stop(rig);
 
 		ret = elektor507_ftdi_write_data(rig, priv->FT_Out_Buffer, priv->Buf_adr);
+
 		if (ret != 0)
 			return -RIG_EIO;
 	}
