@@ -2,21 +2,20 @@
  *  Hamlib Lowe backend - HF-235 description
  *  Copyright (c) 2003 by Stephane Fillod
  *
- *	$Id: hf235.c,v 1.4 2006-10-07 18:01:31 csete Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -95,7 +94,7 @@ const struct rig_caps hf235_caps = {
 		RIG_CHAN_END,	/* FIXME */
 	},
 
-.rx_range_list1 =  { 
+.rx_range_list1 =  {
 	{kHz(30),MHz(30),HF235_MODES,-1,-1,HF235_VFO},
 	RIG_FRNG_END,
   },
