@@ -36,6 +36,7 @@
 #include "num_stdio.h"
 
 #include "rs.h"
+#include "gp2000.h"
 
 
 #define BUFSZ 64
@@ -301,8 +302,8 @@ const char * rs_get_info(RIG *rig)
 #define ID_QUERY BOM "*IDN?" EOM
 
 	retval = rs_transaction(rig, ID_QUERY, strlen(ID_QUERY), infobuf, &info_len);
-    if (retval < 0)
-        return NULL;
+	if (retval < 0)
+		return NULL;
 
 	return infobuf;
 }
@@ -328,6 +329,7 @@ DECLARE_INITRIG_BACKEND(rs)
 
 	rig_register(&esmc_caps);
 	rig_register(&eb200_caps);
+	rig_register(&xk2100_caps);
 
 	return RIG_OK;
 }
