@@ -42,6 +42,7 @@
 #include <errno.h>  /* Error number definitions */
 #include <sys/types.h>
 #include <unistd.h>
+#include <time.h>
 
 #ifdef ANDROID
 #  include <android/log.h>
@@ -54,6 +55,7 @@
 
 
 static int rig_debug_level = RIG_DEBUG_TRACE;
+static int rig_debug_time_stamp = 0;
 static FILE *rig_debug_stream;
 static vprintf_cb_t rig_vprintf_cb;
 static rig_ptr_t rig_vprintf_arg;
@@ -128,6 +130,30 @@ int HAMLIB_API rig_need_debug(enum rig_debug_level_e debug_level)
     return (debug_level <= rig_debug_level);
 }
 
+/**
+ * \param debug_time_stamp
+ * \brief Enbable/disable time stamp on debug output
+ */
+void HAMLIB_API rig_set_debug_time_stamp(int flag)
+{
+    rig_debug_time_stamp = flag;
+}
+
+
+char *date_strget(char *buf,int buflen)
+{
+	time_t mytime;
+	struct tm *mytm;
+        struct timeval tv;
+	mytime=time(NULL);
+	mytm = gmtime(&mytime);
+        gettimeofday(&tv,NULL);
+	strftime(buf,buflen,"%Y-%m-%d:%H:%M:%S.",mytm);
+	char tmp[16];
+	sprintf(tmp,"%06ld",tv.tv_usec);
+	strcat(buf,tmp);
+	return buf;
+}
 
 /**
  * \param debug_level
@@ -157,7 +183,10 @@ void HAMLIB_API rig_debug(enum rig_debug_level_e debug_level,
         {
             rig_debug_stream = stderr;
         }
-
+        if (rig_debug_time_stamp) {
+            char buf[256];
+            fprintf(rig_debug_stream,"%s: ",date_strget(buf,sizeof(buf)));
+        }
         vfprintf(rig_debug_stream, fmt, ap);
         fflush(rig_debug_stream);
     }
