@@ -27,36 +27,43 @@
 #include "iofunc.h"
 
 #ifdef HAVE_LINUX_PARPORT_H
-#include <linux/parport.h>
+#  include <linux/parport.h>
 #endif
 
 #ifndef PARPORT_CONTROL_STROBE
-#define PARPORT_CONTROL_STROBE    0x1
+#  define PARPORT_CONTROL_STROBE    0x1
 #endif
+
 #ifndef PARPORT_CONTROL_AUTOFD
-#define PARPORT_CONTROL_AUTOFD    0x2
+#  define PARPORT_CONTROL_AUTOFD    0x2
 #endif
+
 #ifndef PARPORT_CONTROL_INIT
-#define PARPORT_CONTROL_INIT      0x4
+#  define PARPORT_CONTROL_INIT      0x4
 #endif
+
 #ifndef PARPORT_CONTROL_SELECT
-#define PARPORT_CONTROL_SELECT    0x8
+#  define PARPORT_CONTROL_SELECT    0x8
 #endif
 
 #ifndef PARPORT_STATUS_ERROR
-#define PARPORT_STATUS_ERROR      0x8
+#  define PARPORT_STATUS_ERROR      0x8
 #endif
+
 #ifndef PARPORT_STATUS_SELECT
-#define PARPORT_STATUS_SELECT     0x10
+#  define PARPORT_STATUS_SELECT     0x10
 #endif
+
 #ifndef PARPORT_STATUS_PAPEROUT
-#define PARPORT_STATUS_PAPEROUT   0x20
+#  define PARPORT_STATUS_PAPEROUT   0x20
 #endif
+
 #ifndef PARPORT_STATUS_ACK
-#define PARPORT_STATUS_ACK        0x40
+#  define PARPORT_STATUS_ACK        0x40
 #endif
+
 #ifndef PARPORT_STATUS_BUSY
-#define PARPORT_STATUS_BUSY       0x80
+#  define PARPORT_STATUS_BUSY       0x80
 #endif
 
 __BEGIN_DECLS
@@ -69,10 +76,16 @@ int par_ptt_get(hamlib_port_t *p, ptt_t *pttx);
 int par_dcd_get(hamlib_port_t *p, dcd_t *dcdx);
 
 extern HAMLIB_EXPORT(int) par_write_data(hamlib_port_t *p, unsigned char data);
-extern HAMLIB_EXPORT(int) par_write_control(hamlib_port_t *p, unsigned char control);
+extern HAMLIB_EXPORT(int) par_write_control(hamlib_port_t *p,
+                                            unsigned char control);
+
 extern HAMLIB_EXPORT(int) par_read_data(hamlib_port_t *p, unsigned char *data);
-extern HAMLIB_EXPORT(int) par_read_control(hamlib_port_t *p, unsigned char *control);
-extern HAMLIB_EXPORT(int) par_read_status(hamlib_port_t *p, unsigned char *status);
+extern HAMLIB_EXPORT(int) par_read_control(hamlib_port_t *p,
+                                           unsigned char *control);
+
+extern HAMLIB_EXPORT(int) par_read_status(hamlib_port_t *p,
+                                          unsigned char *status);
+
 extern HAMLIB_EXPORT(int) par_lock(hamlib_port_t *p);
 extern HAMLIB_EXPORT(int) par_unlock(hamlib_port_t *p);
 
