@@ -81,7 +81,7 @@ DEFINE_INITROT_BACKEND(celestron);
 DEFINE_INITROT_BACKEND(ether6);
 DEFINE_INITROT_BACKEND(cnctrk);
 DEFINE_INITROT_BACKEND(prosistel);
-
+DEFINE_INITROT_BACKEND(meade);
 
 /**
  *  \def ROT_BACKEND_LIST
@@ -118,6 +118,7 @@ static struct
     { ROT_ETHER6, ROT_BACKEND_ETHER6, ROT_FUNCNAMA(ether6) },
     { ROT_CNCTRK, ROT_BACKEND_CNCTRK, ROT_FUNCNAMA(cnctrk) },
     { ROT_PROSISTEL, ROT_BACKEND_PROSISTEL, ROT_FUNCNAMA(prosistel) },
+    { ROT_MEADE, ROT_BACKEND_MEADE, ROT_FUNCNAMA(meade) },
     { 0, NULL }, /* end */
 };
 
