@@ -87,7 +87,7 @@ void usage(void);
  * NB: do NOT use -W since it's reserved by POSIX.
  * TODO: add an option to read from a file
  */
-#define SHORT_OPTIONS "+m:r:p:d:P:D:s:c:t:lC:LuonvhV"
+#define SHORT_OPTIONS "+m:r:p:d:P:D:s:c:t:lC:LuonvhVZ"
 static struct option long_options[] =
 {
     {"model",           1, 0, 'm'},
@@ -105,6 +105,7 @@ static struct option long_options[] =
     {"dump-caps",       0, 0, 'u'},
     {"vfo",             0, 0, 'o'},
     {"no-restore-ai",   0, 0, 'n'},
+    {"debug-time-stamps",0, 0, 'Z'},
 #ifdef HAVE_READLINE_HISTORY
     {"read-history",    0, 0, 'i'},
     {"save-history",    0, 0, 'I'},
@@ -399,6 +400,10 @@ int main(int argc, char *argv[])
             dump_caps_opt++;
             break;
 
+        case 'Z':
+	    rig_set_debug_time_stamp(1);
+	    break;
+
         default:
             usage();    /* unknown option? */
             exit(1);
@@ -541,13 +546,10 @@ int main(int argc, char *argv[])
                 fprintf(stderr, "Warning: %s is not a directory!\n", hist_dir);
             }
 
-            hist_path = (char *)calloc((sizeof(char)
-                                        * (strlen(hist_dir)
-                                           + strlen(hist_file) + 1)),
-                                       sizeof(char));
+            int hist_path_size = sizeof(char)*(strlen(hist_dir)+strlen(hist_file) + 1);
+            hist_path = (char *)calloc(hist_path_size, sizeof(char));
 
-            strncpy(hist_path, hist_dir, strlen(hist_dir));
-            strncat(hist_path, hist_file, strlen(hist_file));
+            snprintf(hist_path, hist_path_size, "%s%s", hist_dir, hist_file);
         }
 
         if (rd_hist && hist_path)
@@ -567,7 +569,7 @@ int main(int argc, char *argv[])
 
     do
     {
-        retcode = rigctl_parse(my_rig, stdin, stdout, argv, argc);
+      retcode = rigctl_parse(my_rig, stdin, stdout, argv, argc, NULL);
 
         if (retcode == 2)
         {
@@ -636,6 +638,7 @@ void usage(void)
         "  -I, --save-history            save current interactive session history\n"
 #endif
         "  -v, --verbose                 set verbose mode, cumulative (-v to -vvvvv)\n"
+        "  -Z, --debug-time-stamps       enable time stamps for debug messages\n"
         "  -h, --help                    display this help and exit\n"
         "  -V, --version                 output version information and exit\n\n"
     );
