@@ -90,12 +90,6 @@ extern int read_history();
 /* Hash table implementation See:  http://uthash.sourceforge.net/ */
 #include "uthash.h"
 
-#ifdef HAVE_PTHREAD
-#  include <pthread.h>
-
-static pthread_mutex_t rig_mutex = PTHREAD_MUTEX_INITIALIZER;
-#endif
-
 #define STR1(S) #S
 #define STR(S) STR1(S)
 
@@ -599,9 +593,13 @@ extern int vfo_mode;
 extern char send_cmd_term;
 int ext_resp = 0;
 unsigned char resp_sep = '\n';      /* Default response separator */
+/* Note that vfo_mode and ext_resp are not thread safe
+ * So to run either a vfo_mode or ext_resp mode rigctld it needs to be
+ * on a separate rigctld instance on a different port.  One port per vfo_mode/ext_resp combination for a maximum of 4 instances/ports to cover all 4 combos
+ * Significant rewrite to fix this for 1 instance
+ */
 
-
-int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
+int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc, sync_cb_t sync_cb)
 {
     int retcode;        /* generic return code from functions */
     unsigned char cmd;
@@ -1102,11 +1100,9 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
 #endif
             /* The starting position of the source string is the first
-             * character past the initial '\'.  Using MAXNAMSIZ for the
-             * length leaves enough space for the '\0' string terminator in the
-             * cmd_name array.
+             * character past the initial '\'.  
              */
-            strncpy(cmd_name, parsed_input[0] + 1, MAXNAMSIZ);
+            snprintf(cmd_name, sizeof(cmd_name), "%s", parsed_input[0] + 1);
 
             /* Sanity check as valid multiple character commands consist of
              * alpha-numeric characters and the underscore ('_') character.
@@ -1212,7 +1208,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
             if (rp_hist_buf)
             {
-                strncat(rp_hist_buf, " ", 1);
+                strncat(rp_hist_buf, " ", 2);
                 strncat(rp_hist_buf, parsed_input[x], MAXNAMSIZ);
             }
 
@@ -1299,7 +1295,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
             if (rp_hist_buf)
             {
-                strncat(rp_hist_buf, " ", 1);
+                strncat(rp_hist_buf, " ", 2);
                 strncat(rp_hist_buf, parsed_input[x], MAXARGSZ);
             }
 
@@ -1362,7 +1358,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
             if (rp_hist_buf)
             {
-                strncat(rp_hist_buf, " ", 1);
+                strncat(rp_hist_buf, " ", 2);
                 strncat(rp_hist_buf, parsed_input[x], MAXARGSZ);
             }
 
@@ -1428,7 +1424,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
             if (rp_hist_buf)
             {
-                strncat(rp_hist_buf, " ", 1);
+                strncat(rp_hist_buf, " ", 2);
                 strncat(rp_hist_buf, parsed_input[x], MAXARGSZ);
             }
 
@@ -1494,7 +1490,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
             if (rp_hist_buf)
             {
-                strncat(rp_hist_buf, " ", 1);
+                strncat(rp_hist_buf, " ", 2);
                 strncat(rp_hist_buf, parsed_input[x], MAXARGSZ);
             }
 
@@ -1517,14 +1513,7 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 
 #endif  /* HAVE_LIBREADLINE */
 
-
-    /*
-     * mutex locking needed because rigctld is multithreaded
-     * and hamlib is not MT-safe
-     */
-#ifdef HAVE_PTHREAD
-    pthread_mutex_lock(&rig_mutex);
-#endif
+    if (sync_cb) sync_cb (1);   /* lock if necessary */
 
     if (!prompt)
     {
@@ -1577,11 +1566,9 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
                                         p2 ? p2 : "",
                                         p3 ? p3 : "");
 
-#ifdef HAVE_PTHREAD
-    pthread_mutex_unlock(&rig_mutex);
-#endif
-
+    if (sync_cb) sync_cb (0);   /* unlock if necessary */
 
+    if (retcode == RIG_EIO) return retcode;
     if (retcode != RIG_OK)
     {
         /* only for rigctld */
